import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React, { Suspense } from 'react';
import PropTypes from 'prop-types';
import { Route, Switch, Redirect } from 'react-router';
/**
 * Routing component that renders different child components
 * depending on route
 *
 * A placeholder component can be specified to temporarily
 * display while a child component is loading.
 */

export function RouterOutlet(props) {
  const {
    routes,
    placeholder
  } = props,
        outletProps = _objectWithoutPropertiesLoose(props, ["routes", "placeholder"]);

  const redirectJsx = (route, index) => {
    const r = route;
    return React.createElement(Redirect, {
      key: index,
      from: r.path,
      exact: r.exact,
      strict: r.strict,
      to: r.redirectTo,
      push: r.push
    });
  };

  const fallbackJsx = (route, index) => {
    const r = route;
    return React.createElement(Redirect, {
      key: index,
      from: r.path,
      exact: r.exact,
      strict: r.strict,
      to: r.fallback,
      push: r.push
    });
  };

  const routeJsx = (route, index) => {
    const r = route;
    return React.createElement(Route, {
      key: index,
      path: r.path,
      exact: r.exact,
      strict: r.strict,
      render: props => Suspense ? React.createElement(Suspense, {
        fallback: placeholder || React.createElement("div", null)
      }, React.createElement(r.component, _extends({}, outletProps, r.componentProps, {
        routes: r.routes
      }))) : React.createElement(r.component, _extends({}, outletProps, r.componentProps, {
        routes: r.routes
      }))
    });
  };

  return React.createElement(Switch, null, routes.map((route, index) => {
    route = resolveFromProps(route, props);
    return 'redirectTo' in route ? redirectJsx(route, index) : 'canEnter' in route && !route.canEnter(props, route) ? fallbackJsx(route, index) : routeJsx(route, index);
  }));
}

function resolveFromProps(route, props) {
  const resolveRedirect = val => typeof val === 'function' ? val(props, route) : val;

  if ('redirectTo' in route) return _extends({}, route, {
    redirectTo: resolveRedirect(route.redirectTo)
  });
  if ('fallback' in route) return _extends({}, route, {
    fallback: resolveRedirect(route.fallback)
  });
  return route;
}

const routePropType = PropTypes.shape({
  path: PropTypes.oneOfType([PropTypes.string, PropTypes.arrayOf(PropTypes.string)]),
  exact: PropTypes.bool,
  strict: PropTypes.bool,
  component: PropTypes.oneOfType([PropTypes.func, PropTypes.object]),
  canEnter: PropTypes.func,
  fallback: PropTypes.oneOfType([PropTypes.func, PropTypes.string, PropTypes.object]),
  redirectTo: PropTypes.oneOfType([PropTypes.func, PropTypes.string, PropTypes.object]),
  push: PropTypes.bool
});
RouterOutlet.propTypes = {
  routes: PropTypes.arrayOf(routePropType).isRequired,
  placeholder: PropTypes.oneOfType([PropTypes.func, PropTypes.object])
};
export default RouterOutlet;