"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.RouterOutlet = RouterOutlet;
exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _objectWithoutPropertiesLoose2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutPropertiesLoose"));

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactRouter = require("react-router");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

/**
 * Routing component that renders different child components
 * depending on route
 *
 * A placeholder component can be specified to temporarily
 * display while a child component is loading.
 */
function RouterOutlet(props) {
  var routes = props.routes,
      placeholder = props.placeholder,
      outletProps = (0, _objectWithoutPropertiesLoose2.default)(props, ["routes", "placeholder"]);

  var redirectJsx = function redirectJsx(route, index) {
    var r = route;
    return _react.default.createElement(_reactRouter.Redirect, {
      key: index,
      from: r.path,
      exact: r.exact,
      strict: r.strict,
      to: r.redirectTo,
      push: r.push
    });
  };

  var fallbackJsx = function fallbackJsx(route, index) {
    var r = route;
    return _react.default.createElement(_reactRouter.Redirect, {
      key: index,
      from: r.path,
      exact: r.exact,
      strict: r.strict,
      to: r.fallback,
      push: r.push
    });
  };

  var routeJsx = function routeJsx(route, index) {
    var r = route;
    return _react.default.createElement(_reactRouter.Route, {
      key: index,
      path: r.path,
      exact: r.exact,
      strict: r.strict,
      render: function render(props) {
        return _react.Suspense ? _react.default.createElement(_react.Suspense, {
          fallback: placeholder || _react.default.createElement("div", null)
        }, _react.default.createElement(r.component, (0, _extends2.default)({}, outletProps, r.componentProps, {
          routes: r.routes
        }))) : _react.default.createElement(r.component, (0, _extends2.default)({}, outletProps, r.componentProps, {
          routes: r.routes
        }));
      }
    });
  };

  return _react.default.createElement(_reactRouter.Switch, null, routes.map(function (route, index) {
    route = resolveFromProps(route, props);
    return 'redirectTo' in route ? redirectJsx(route, index) : 'canEnter' in route && !route.canEnter(props, route) ? fallbackJsx(route, index) : routeJsx(route, index);
  }));
}

function resolveFromProps(route, props) {
  var resolveRedirect = function resolveRedirect(val) {
    return typeof val === 'function' ? val(props, route) : val;
  };

  if ('redirectTo' in route) return (0, _extends2.default)({}, route, {
    redirectTo: resolveRedirect(route.redirectTo)
  });
  if ('fallback' in route) return (0, _extends2.default)({}, route, {
    fallback: resolveRedirect(route.fallback)
  });
  return route;
}

var routePropType = _propTypes.default.shape({
  path: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.arrayOf(_propTypes.default.string)]),
  exact: _propTypes.default.bool,
  strict: _propTypes.default.bool,
  component: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.object]),
  canEnter: _propTypes.default.func,
  fallback: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string, _propTypes.default.object]),
  redirectTo: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.string, _propTypes.default.object]),
  push: _propTypes.default.bool
});

RouterOutlet.propTypes = {
  routes: _propTypes.default.arrayOf(routePropType).isRequired,
  placeholder: _propTypes.default.oneOfType([_propTypes.default.func, _propTypes.default.object])
};
var _default = RouterOutlet;
exports.default = _default;